==> 0.1.tar.gz: hypervideo-gui/README.md <==
# Simple Hypervideo Downloader GUI

Simple Hypervideo Downloader GUI is intended
to serve as a basic interface for downloading YouTube videos/audio
that can be easily shared and used by non-programmers.

![](images/screenshot.png)

### Dependencies
- PyQt5 (`pacman -S python-pyqt5`)
- hypervideo (`pacman -S hypervideo`)
- ffmpeg (`pacman -S ffmpeg`)

### Install

`pacman -S hypervideo-gui`

### Usage
1. Run `hypervideo-gui` in terminal
2. Enter the URL of the video you want to download into the top "URL" textbox.
3. Then enter the folder to save the video to in the "Output Folder" textbox.
4. Next choose the video format
    - To download the highest quality of video, select the video format `Video - Best Quality`
    - If you only want the audio (saved as .mp3), select `Audio Only - Best Quality`
    - If you want another video format, click `Detect All Available Formats`, which will
      fetch the available video formats and populate the dropdown with the available formats.
      Warning: some of these formats may be video only or audio only!
5. Click the Download button.

### Config directory downloads

For default, download path settings are saved in file
`~/.config/hypervideo_gui/hypervideo_gui_state.json`

### Developer Setup
Just set up Python3 with libraries PyQt5.
`cd` to the repository path, and then `python script.py`.

### Generate Tarball

Require `pandoc` for generate README.txt

    # pacman -S pandoc

Run this to generate tarball:

    $ make dist

### Troubleshooting
Make sure you have the latest version of hypervideo! Use `pacman -Sy hypervideo`in the command line.
For downloading audio only, you may need to install ffmpeg to handle the mp4 -> mp3 conversion

## License
This work is under the License [GNU GPLv3+](LICENSE)

==> 1.0.3.tar.gz: hypervideo-gui/README.md <==
# Simple Hypervideo Downloader GUI

Simple Hypervideo Downloader GUI is intended
to serve as a basic interface for downloading YouTube videos/audio
that can be easily shared and used by non-programmers.

![](images/screenshot.png)

### Dependencies
- PyQt5 (`pacman -S python-pyqt5`)
- hypervideo (`pacman -S hypervideo`)
- ffmpeg (`pacman -S ffmpeg`)

### Install

`pacman -S hypervideo-gui`

### Usage
1. Run `hypervideo-gui` in terminal
2. Enter the URL of the video you want to download into the top "URL" textbox.
3. Then enter the folder to save the video to in the "Output Folder" textbox.
4. Next choose the video format
    - To download the highest quality of video, select the video format `Video - Best Quality`
    - If you only want the audio (saved as .mp3), select `Audio Only - Best Quality`
    - If you want another video format, click `Get Formats`, which will
      fetch the available video formats and populate the dropdown with the available formats.
      Warning: some of these formats may be video only or audio only!
5. Click the Download button.

### Developer Setup
Just set up Python3 with libraries PyQt5.

Run `make demo` or `python script.py`


#### Debug mode

`$ make DEBUG=1 demo`

or

`$ python script.py -v`

### Generate Tarball

Require `pandoc` for generate README.txt

    # pacman -S pandoc

Run this to generate tarball:

    $ make dist

### Troubleshooting
Make sure you have the latest version of hypervideo! Use `pacman -Sy hypervideo`in the command line.
For downloading audio only, you may need to install ffmpeg to handle the mp4 -> mp3 conversion

## License
This work is under the License [GNU GPLv3+](LICENSE)
